==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-powermanagement/lxqt-config-powermanagement/lxqt-config-powermanagement_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Einstellungen zur Batterieüberwachung</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>Batterieüberwachu&amp;ng aktivieren</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Warnung:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> Sekunden</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Ladung ist niedrig bei:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Symbole vom Thema nutzen:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="125"/>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>Laden</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>Entladen</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Falls Ladung niedrig:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Zeige Symbol:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>eingebaut</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>Ladung: %1 %</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="20"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>Leer&amp;laufüberwachung aktivieren</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="41"/>
        <source>When idle then:</source>
        <translation>Falls Leerlauf:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="60"/>
        <source>Idle time:</source>
        <translation>Zeit im Leerlauf:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="73"/>
        <source> minutes</source>
        <translation> Minuten</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="86"/>
        <source> seconds</source>
        <translation> Sekunden</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="26"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>Decke&amp;lüberwachung aktivieren</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="41"/>
        <source>Action when lid is closed</source>
        <translation>Aktion falls Deckel geschlossen wird</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="53"/>
        <location filename="../../../lidwatchersettings.ui" line="118"/>
        <source>On Battery</source>
        <translation>Batterie</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="61"/>
        <source>Nothing</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="66"/>
        <source>Suspend</source>
        <translation>Ruhen</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="71"/>
        <source>Hibernate</source>
        <translation>Schlafen</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="76"/>
        <source>Shut down</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="84"/>
        <location filename="../../../lidwatchersettings.ui" line="128"/>
        <source>On AC</source>
        <translation>Am Netz</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="97"/>
        <source>When &amp;using external monitor</source>
        <translation>Falls externer Bildschirm ben&amp;utzt</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.cpp" line="34"/>
        <source>Power Management Settings</source>
        <translation>Einstellungen der Energieverwaltung</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="37"/>
        <source>Battery</source>
        <translation>Batterie</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="41"/>
        <source>Lid</source>
        <translation>Deckel</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="45"/>
        <source>Idle</source>
        <translation>Leerlauf</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="36"/>
        <source>Lock screen</source>
        <translation>Bildschirm sperren</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="37"/>
        <source>Suspend</source>
        <translation>Ruhen</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="38"/>
        <source>Hibernate</source>
        <translation>Schlafen</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="39"/>
        <source>Shutdown</source>
        <translation>Herunterfahren</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-powermanagement/lxqt-config-powermanagement/lxqt-config-powermanagement_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Einstellungen zur Batterieüberwachung</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>Batterieüberwachu&amp;ng aktivieren</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Warnung:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> Sekunden</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Ladung ist niedrig bei:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Symbole vom Thema nutzen:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="125"/>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>Laden</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>Entladen</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Falls Ladung niedrig:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Zeige Symbol:</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>eingebaut</translation>
    </message>
    <message>
        <location filename="../../../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>Ladung: %1 %</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="20"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>Leer&amp;laufüberwachung aktivieren</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="41"/>
        <source>When idle then:</source>
        <translation>Falls Leerlauf:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="60"/>
        <source>Idle time:</source>
        <translation>Zeit im Leerlauf:</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="73"/>
        <source> minutes</source>
        <translation> Minuten</translation>
    </message>
    <message>
        <location filename="../../../idlenesswatchersettings.ui" line="86"/>
        <source> seconds</source>
        <translation> Sekunden</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="26"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>Decke&amp;lüberwachung aktivieren</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="41"/>
        <source>Action when lid is closed</source>
        <translation>Aktion falls Deckel geschlossen wird</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="53"/>
        <location filename="../../../lidwatchersettings.ui" line="118"/>
        <source>On Battery</source>
        <translation>Batterie</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="61"/>
        <source>Nothing</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="66"/>
        <source>Suspend</source>
        <translation>Ruhen</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="71"/>
        <source>Hibernate</source>
        <translation>Schlafen</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="76"/>
        <source>Shut down</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="84"/>
        <location filename="../../../lidwatchersettings.ui" line="128"/>
        <source>On AC</source>
        <translation>Am Netz</translation>
    </message>
    <message>
        <location filename="../../../lidwatchersettings.ui" line="97"/>
        <source>When &amp;using external monitor</source>
        <translation>Falls externer Bildschirm ben&amp;utzt</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.cpp" line="34"/>
        <source>Power Management Settings</source>
        <translation>Einstellungen der Energieverwaltung</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="37"/>
        <source>Battery</source>
        <translation>Batterie</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="41"/>
        <source>Lid</source>
        <translation>Deckel</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="45"/>
        <source>Idle</source>
        <translation>Leerlauf</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="36"/>
        <source>Lock screen</source>
        <translation>Bildschirm sperren</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="37"/>
        <source>Suspend</source>
        <translation>Ruhen</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="38"/>
        <source>Hibernate</source>
        <translation>Schlafen</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="39"/>
        <source>Shutdown</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <location filename="../../../helpers.cpp" line="40"/>
        <source>Turn Off monitor(s)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
